@@ -25,7 +25,8 @@ def toJson(msg, includeHeader=False):
     msgClass = Messaging.MsgClass(msg.hdr)
     for fieldInfo in msgClass.fields:
         if(fieldInfo.count == 1):
-            if msg.hdr.GetDataLength() < int(fieldInfo.get.offset) + int(fieldInfo.get.size):
+            #TODO Broken for arrays-of-structs acting like parallel arrays!
+            if not fieldInfo.exists(msg):
                 break
             if len(fieldInfo.bitfieldInfo) == 0:
                 pythonObj[fieldInfo.name] = str(Messaging.get(msg, fieldInfo))
@@ -36,7 +37,8 @@ def toJson(msg, includeHeader=False):
             arrayList = []
             terminate = 0
             for i in range(0,fieldInfo.count):
-                if msg.hdr.GetDataLength() < int(fieldInfo.get.offset) + i*int(fieldInfo.get.size):
+                #TODO Broken for arrays-of-structs acting like parallel arrays!
+                if not fieldInfo.exists(msg, i):
                     terminate = 1
                     break
                 arrayList.append(str(Messaging.get(msg, fieldInfo, i)))
@@ -72,7 +74,8 @@ def jsonToMsg(jsonString):
                     for i in range(0,len(fieldValue)):
                         Messaging.set(msg, fieldInfo, fieldValue[i], i)
                         if terminationLen != None:
-                            terminationLen = max(terminationLen, int(fieldInfo.get.offset) + int(fieldInfo.get.size)*(i+1))
+                            #TODO Broken for arrays-of-structs acting like parallel arrays!
+                            terminationLen = max(terminationLen, fieldInfo.end_location(i))
                 elif isinstance(fieldValue, dict):
                     #print(fieldName + " dict type is " + str(type(fieldValue)))
                     if fieldInfo.bitfieldInfo:
@@ -84,9 +87,11 @@ def jsonToMsg(jsonString):
                     Messaging.set(msg, fieldInfo, fieldValue)
                     if terminationLen != None:
                         if fieldInfo.type == "string":
-                            terminationLen = max(terminationLen, int(fieldInfo.get.offset) + int(fieldInfo.get.size) * len(fieldValue))
+                            #TODO Broken for arrays-of-structs acting like parallel arrays!
+                            terminationLen = max(terminationLen, fieldInfo.end_location(len(fieldValue)-1))
                         else:
-                            terminationLen = max(terminationLen, int(fieldInfo.get.offset) + int(fieldInfo.get.size))
+                            #TODO Broken for arrays-of-structs acting like parallel arrays!
+                            terminationLen = max(terminationLen, fieldInfo.end_location())
     if terminationLen != None:
         msg.hdr.SetDataLength(terminationLen)
     return msg
